==> haskell-interpolatedstring-perl6-1.0.1-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-interpolatedstring-perl6.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: interpolatedstring-perl6
version: 1.0.1
id: interpolatedstring-perl6-1.0.1-AkufcZznhHw5zpsT6XgR3l
key: interpolatedstring-perl6-1.0.1-AkufcZznhHw5zpsT6XgR3l
license: LicenseRef-PublicDomain
copyright: Audrey Tang
maintainer: Audrey Tang <audreyt@audreyt.org>
author: Audrey Tang
stability: stable
synopsis: QuasiQuoter for Perl6-style multi-line interpolated strings
description:
    QuasiQuoter for Perl6-style multi-line interpolated strings with \"q\", \"qq\" and \"qc\" support.
category: Data
abi: 16a2fa88dcb6f404c2ddc8b06dc1d6d1
exposed: True
exposed-modules:
    Text.InterpolatedString.Perl6
import-dirs: /usr/lib/ghc-8.6.3/site-local/interpolatedstring-perl6-1.0.1
library-dirs: /usr/lib/ghc-8.6.3/site-local/interpolatedstring-perl6-1.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-interpolatedstring-perl6
hs-libraries: HSinterpolatedstring-perl6-1.0.1-AkufcZznhHw5zpsT6XgR3l
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    haskell-src-meta-0.8.0.3-Lr4uIfvRgZK9vq5DR4jmxB
    template-haskell-2.14.0.0 text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-interpolatedstring-perl6/html/interpolatedstring-perl6.haddock
haddock-html: /usr/share/doc/haskell-interpolatedstring-perl6/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-interpolatedstring-perl6-1.0.1-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-interpolatedstring-perl6.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: interpolatedstring-perl6
version: 1.0.1
id: interpolatedstring-perl6-1.0.1-4f9xch4qDByFkwwuKAHZyf
key: interpolatedstring-perl6-1.0.1-4f9xch4qDByFkwwuKAHZyf
license: LicenseRef-PublicDomain
copyright: Audrey Tang
maintainer: Audrey Tang <audreyt@audreyt.org>
author: Audrey Tang
stability: stable
synopsis: QuasiQuoter for Perl6-style multi-line interpolated strings
description:
    QuasiQuoter for Perl6-style multi-line interpolated strings with \"q\", \"qq\" and \"qc\" support.
category: Data
abi: 3af7e30c02945e45eb0b2a1c35dde211
exposed: True
exposed-modules:
    Text.InterpolatedString.Perl6
import-dirs: /usr/lib/ghc-8.6.3/site-local/interpolatedstring-perl6-1.0.1
library-dirs: /usr/lib/ghc-8.6.3/site-local/interpolatedstring-perl6-1.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-interpolatedstring-perl6
hs-libraries: HSinterpolatedstring-perl6-1.0.1-4f9xch4qDByFkwwuKAHZyf
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    haskell-src-meta-0.8.0.3-56x4OHOUXM55SJyiQWw8MD
    template-haskell-2.14.0.0 text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-interpolatedstring-perl6/html/interpolatedstring-perl6.haddock
haddock-html: /usr/share/doc/haskell-interpolatedstring-perl6/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
